/***********************************************************************
*
* Copyright (c) 2021-2022 Barbara Geller and Ansel Sermersheim
*
* This example is free software, released under the BSD 2-Clause license.
* For license details refer to LICENSE provided with this project.
*
* CopperSpice is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
*
* https://opensource.org/licenses/BSD-2-Clause
*
***********************************************************************/

#include <QtCore>
#include <QtGui>

class MainWindow : public QWidget
{
 public:
   MainWindow();

 private:
   void setInteger();
   void setDouble();

   QLineEdit *integer_text;
   QLineEdit *double_text;
};

MainWindow::MainWindow()
{
   setMinimumSize(700, 350);

   QPushButton *integer_pb = new QPushButton("Integer");
   integer_text = new QLineEdit();

   QPushButton *double_pb = new QPushButton("Double");
   double_text = new QLineEdit();

   QPushButton *close_pb = new QPushButton();
   close_pb->setText("Close");

   QGridLayout *grid1 = new QGridLayout();
   grid1->setContentsMargins(75, 45, 75, 25);
   grid1->setHorizontalSpacing(20);
   grid1->setVerticalSpacing(45);

   grid1->addWidget(integer_pb, 0, 0);
   grid1->addWidget(integer_text, 0, 1);

   grid1->addWidget(double_pb, 1, 0);
   grid1->addWidget(double_text, 1, 1);

   QHBoxLayout *layout1 = new QHBoxLayout();
   layout1->addStretch();
   layout1->addWidget(close_pb);
   layout1->addStretch();

   QVBoxLayout *layoutMain = new QVBoxLayout(this);
   layoutMain->addLayout(grid1);
   layoutMain->addSpacing(75);
   layoutMain->addLayout(layout1);

   connect(integer_pb, &QPushButton::clicked, this, &MainWindow::setInteger);
   connect(double_pb,  &QPushButton::clicked, this, &MainWindow::setDouble);

   connect(close_pb, &QPushButton::clicked, this, &QWidget::close);
}

// 1
void MainWindow::setInteger()
{
   bool ok;

   int value = QInputDialog::getInt(this, "Integer",
         "Percentage:", 25, 0, 100, 1, &ok);

   if (ok) {
      integer_text->setText(QString("%1%").formatArg(value));
   }
}

void MainWindow::setDouble()
{
   bool ok;
   double value = QInputDialog::getDouble(this, "Double",
         "Unit Price:", 37.56, -10000, 10000, 2, &ok);

   if (ok) {
      double_text->setText(QString("$%1").formatArg(value));
   }
}

int main(int argc, char *argv[])
{
   QApplication app(argc, argv);

   MainWindow *window = new MainWindow();
   window->show();

   return app.exec();
}

